#include <iostream>
#include <fstream>
#include <string>
#include <vector>
#include <sstream>

#include "../include/BendData.h"
#include "../include/BendAllowance.h"
#include "../include/BendDeduction.h"
#include "../include/DataLoad.h"
#include "../include/DataSave.h"
#include "../include/Deserializer.h"
#include "../include/FormingTool.h"
#include "../include/Kfactor.h"
#include "../include/Serializer.h"
#include "../include/Setback.h"
#include "../include/Tonnage.h"

int main()
{
	std::string fileName;
	std::string dataToSave;

	// Welcome message
	std::cout << "Welcome to BendCalc - Metal Forming and Bending Operations Calculator\n";

	// Main menu loop
	while (true)
	{
		std::cout << "\nSelect an operation:\n";
		std::cout << "1. Calculate Bend Deduction\n";
		std::cout << "2. Load Data\n";
		std::cout << "3. Save Data\n";
		std::cout << "4. Exit\n";
		std::cout << "Enter your choice: ";

		int choice;
		std::cin >> choice;

		switch (choice)
		{
		case 1:
		{
			// Calculate Bend Deduction
			std::cout << "Enter bend angle (degrees): ";
			double bendAngleDegrees;
			std::cin >> bendAngleDegrees;

			std::cout << "Enter inside bend radius (mm): ";
			double insideRadius;
			std::cin >> insideRadius;

			std::cout << "Enter material thickness (mm): ";
			double materialThickness;
			std::cin >> materialThickness;

			std::cout << "Enter K-factor: ";
			double kFactor;
			std::cin >> kFactor;

			BendDeduction bendCalculator(bendAngleDegrees, insideRadius, materialThickness, kFactor);
			double bendDeduction = bendCalculator.calculateBendDeduction();
			std::cout << "Bend Deduction: " << bendDeduction << " mm\n";
			break;
		}
		case 2:
		{
			// Load Data
			std::cout << "Enter the CSV file name to load: ";
			std::cin >> fileName;

			DataLoad::BendData bendData;							   // Declare a BendData instance
			DataLoad::loadDataFromCSV(fileName, bendData); // Pass the BendData instance

			std::cout << "Data loaded (assuming successful parsing).\n";
			break;
		}
		case 3:
		{
			// Save Data
			std::cout << "Enter the CSV file name to save: ";
			std::cin >> fileName;
			std::cout << "Enter the data to save: ";
			std::cin.ignore(); // Ignore the newline character left by std::cin >> fileName
			std::getline(std::cin, dataToSave);
			saveDataToCSV(fileName, dataToSave);
			std::cout << "Data saved successfully.\n";
			break;
		}
		case 4:
		{
			// Exit
			std::cout << "Exiting...\n";
			return 0;
		}
		default:
		{
			std::cout << "Invalid choice. Please try again.\n";
			break;
		}
		}
	}

	return 0; // This line will never be reached due to the infinite loop above
}
